# Firepup650
Package containing various shorthand things I use, and a few imports I almost always use
#### Change log:
###### v.1.0.9:
Small tweaks, nothing major.
###### v.1.0.8:
Can't install collections. This better fix it.
###### v.1.0.7:
Adds `console` (class), `bcolors` (class), and `Color` (function). Fixes type hinting on various things (Lots of thanks to @bigminiboss!).
###### v.1.0.6:
Hopefully, fixes an issue where the package doesn't install it's dependencies (Again. Hopefully.)
###### v.1.0.5:
Hopefully, fixes an issue where the package doesn't install it's dependencies
###### v.1.0.4:
Subscript errors
###### v.1.0.3:
Dependant errors
###### v.1.0.2:
Random shorthand (litterally)
###### v.1.0.1:
Added animated typing function, sleep shorthand
###### v.1.0.0:
Initial Release!